[![wakatime](https://wakatime.com/badge/github/AsgerJon/WorkToy.svg)](
https://wakatime.com/badge/github/AsgerJon/WorkToy)

# WorkToy v0.49.00

WorkToy collects common utilities. It is available for installation via pip:

```
pip install worktoy
```

Navigate with the table of contents below.

## Table of Contents

- [WorkToy v0.49.00](#worktoy-v04900)
    - [LICENSE](#LICENSE)
    - [Table of Contents](#table-of-contents)
    - [Installation](#installation)
    - [Usage](#usage)
        - [desc](#worktoydesc)
        - [ezdata](#worktoyezdata)
        - [keenum](#worktoykeenum)
        - [meta](#worktoymeta)
        - [parse](#worktoyparse)
        - [text](#worktoytext)
        - [worktest](#worktoyworktest)
        - [yolo](#worktoyyolo)
    - [Development](#development)
    - 
